Baseline Models
===============

.. automodule:: sig_networks.ffn_baseline
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sig_networks.lstm_baseline
   :members:
   :undoc-members:
   :show-inheritance:
